function [goalellipseH, goalCMH] = addellispse(f,x,y,x2,xy,y2,color)
% INPUT:        f  -- handle of the figure 
%                  x,y -- center of the ellipse
%                  inertia -- inertia matrix of the ellipse
%                  color  --- color
% OUTPUT:     hd -- handle of the ellipse

% Peng Yang, Ph.D candidate(Robotics)
% Northwestern Univ,
% 04/25/2006

figure(f);

numellpts = 50;
ellipsepoly = cat(2, cos([1:numellpts]'*2*pi/numellpts), sin([1:numellpts]'*2*pi/numellpts));			
goalellipseH = patch('vertices',ellipsepoly,'faces',[1:numellpts],'edgecolor',color, ...						 					% create circle
        'facecolor','none','LineWidth',1);		

inertia = [x2, -xy; -xy, y2];    
        
        
[u,s,v] = svd(inertia);
% from the definition of moment of inertia:
% http://scienceworld.wolfram.com/physics/MomentofInertiaEllipse.html
xsize = 2*sqrt(s(1,1));
ysize = 2*sqrt(s(2,2));

% make the circle to an ellipse
newellipsex = xsize*get(goalellipseH,'XData');
newellipsey = ysize*get(goalellipseH,'YData');;
set(goalellipseH,'XData',newellipsex,'YData',newellipsey);							 
% rotate the ellipse        
rotate(goalellipseH,[0 0 1], atan2(u(1,2),u(2,2))*180/pi, [0 0 0]);
% translate the ellipse
newxdat = get(goalellipseH,'XData');
newydat = get(goalellipseH,'YData');
set(goalellipseH,'XData',newxdat+x,'YData',newydat+y);				% translate the ellipse to the desired CM

goalCMH= line(x,y,'marker','o', ...																					% use a line object to create a circle
	      'markerfacecolor','none', 'markeredgecolor',color,'markersize',10);

% end of program